critical_bash_patterns

Function critical_bash_patterns 

pub fn critical_bash_patterns() -> &'static [Regex]
Returns the list of critical bash patterns that are checked before execution.

Panics

Panics if any of the internal regular expressions fail to compile (they are static and guaranteed valid on first access).